Learn R Programming

paintingr (version 0.1.0)

paint_palette: Paintings Palette Generator

Description

Paintings Palette Generator

Usage

paint_palette(name, n, type = c("discrete", "continuous"))

Value

A vector of colors.

Arguments

name

Name of desired palette. Choice are: Pearlgirl, Splash, Autumn, Villeneuve, Ophelia, Kitchen, Spring, Strawberries, Seascape, Twilight, Abstract, Vesuvius

n

Number of colors you want.

type

Use "discrete" or "continuous". Use "continuous" to automatically interpolate between colors if you want more colors.

Examples

Run this code
paint_palette("Ophelia")
paint_palette("Ophelia", n=3)
paint_palette("Autumn", n=100, type="continuous")

Run the code above in your browser using DataLab