powered by
Paintings Palette Generator
paint_palette(name, n, type = c("discrete", "continuous"))
A vector of colors.
Name of desired palette. Choice are: Pearlgirl, Splash, Autumn, Villeneuve, Ophelia, Kitchen, Spring, Strawberries, Seascape, Twilight, Abstract, Vesuvius
Pearlgirl
Splash
Autumn
Villeneuve
Ophelia
Kitchen
Spring
Strawberries
Seascape
Twilight
Abstract
Vesuvius
Number of colors you want.
Use "discrete" or "continuous". Use "continuous" to automatically interpolate between colors if you want more colors.
paint_palette("Ophelia") paint_palette("Ophelia", n=3) paint_palette("Autumn", n=100, type="continuous")
Run the code above in your browser using DataLab